<?php

namespace FiloBlu\Countdown\Block;

use FiloBlu\Countdown\Model\CountdownFactory;
use Magento\Framework\DataObject\IdentityInterface;
use Magento\Framework\View\Element\Template;

class Countdown extends Template implements IdentityInterface
{
    protected $_countdownFactory;

    public function __construct(\Magento\Framework\View\Element\Template\Context $context, CountdownFactory $countdownFactory, array $data = [])
    {
        $this->_countdownFactory = $countdownFactory;
        parent::__construct($context, $data);
    }

    public function getCountdown()
    {
        if (!$this->getCountdownEntity() && $this->getCode()) {
            $this->setCountdownEntity($this->_countdownFactory->create()->getCountdownByCode($this->getCode()));
        }
        return $this->getCountdownEntity();
    }

    protected function _toHtml()
    {
        $countdown = $this->getCountdown();

        if (!$countdown) {
            return "";
        }

        if ($countdown->getCode()) {
            $this->setTemplate('FiloBlu_Countdown::countdown/countdown_' . $countdown->getCode() . '.phtml');
        }

        if (!$this->getTemplateFile()) {
            $this->setTemplate('FiloBlu_Countdown::countdown/countdown.phtml');
        }

        return parent::_toHtml();
    }

    public function getIdentities()
    {
        if ($this->getCountdown() && $this->getCountdown()->getId()) {
            return [\FiloBlu\Countdown\Model\Countdown::CACHE_TAG . '_' . $this->getCountdown()->getId()];
        } else {
            return [];
        }

    }

    public function getCacheKeyInfo()
    {
        if ($this->getCountdown() && $this->getCountdown()->getId()) {
            return [
                \FiloBlu\Countdown\Model\Countdown::CACHE_TAG,
                'countdown_' . $this->getCountdown()->getId(),
                'store_' . $this->_storeManager->getStore()->getId(),
            ];
        } else {
            return [];
        }
    }

    public function getCacheLifetime()
    {
        return 86400;
    }
    
    public function getConfig() 
    {
        return $this->_scopeConfig;
    }

}
