<?php
namespace FiloBlu\Countdown\Controller\Adminhtml\Countdown;

use Magento\Backend\App\Action;

class Edit extends \Magento\Backend\App\Action
{
    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry = null;

    /**
     * @var \Magento\Framework\View\Result\PageFactory
     */
    protected $resultPageFactory;

    protected $countdownFactory;
    protected $countdownTranslationsFactory;

    /**
     * @param Action\Context $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param \Magento\Framework\Registry $registry
     */
    public function __construct(
        Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Registry $registry,
        \FiloBlu\Countdown\Model\CountdownFactory $countdownFactory,
        \FiloBlu\Countdown\Model\CountdownTranslationsFactory $countdownTranslationsFactory
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->_coreRegistry = $registry;
        $this->countdownFactory = $countdownFactory;
        $this->countdownTranslationsFactory = $countdownTranslationsFactory;
        parent::__construct($context);
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('FiloBlu_Countdown::config');
    }

    /**
     * Init actions
     *
     * @return \Magento\Backend\Model\View\Result\Page
     */
    protected function _initAction()
    {
        // load layout, set active menu and breadcrumbs
        /** @var \Magento\Backend\Model\View\Result\Page $resultPage */
        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('FiloBlu_Countdown::general_list')
            ->addBreadcrumb(__('Countdown'), __('Countdown'))
            ->addBreadcrumb(__('Manage Countdown'), __('Manage Countdown'));
        return $resultPage;
    }

    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        $storeId = $this->getRequest()->getParam('store',0);

        $model = $this->countdownFactory->create();

        $modelTranslations = $this->countdownTranslationsFactory->create();

        if ($id) {
            $modelTranslations->loadByParentAndStoreId($id,$storeId);

            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager->addError(__('This countdown no longer exists.'));
                /** \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
                $resultRedirect = $this->resultRedirectFactory->create();

                return $resultRedirect->setPath('*/*/');
            }
        }

        $this->_coreRegistry->register('filoblu_countdown', $model);
        $this->_coreRegistry->register('filoblu_countdown_translations', $modelTranslations);

        /** @var \Magento\Backend\Model\View\Result\Page $resultPage */
        $resultPage = $this->_initAction();
        $resultPage->addBreadcrumb(
            $id ? __('Edit Countdown') : __('New Countdown'),
            $id ? __('Edit Countdown') : __('New Countdown')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('Countdown Page'));
        $resultPage->getConfig()->getTitle()
            ->prepend($model->getId() ? $model->getCode() : __('New Countdown'));

        return $resultPage;
    }
}